@@ -8,7 +8,7 @@
 #' myprettyjson <- prettify(myjson)
 #' cat(myprettyjson)
 prettify <- function(txt) {
-	txt = paste(as.character(txt), collapse = "\n")
-	enc = mapEncoding(Encoding(txt))
-	.Call("R_jsonPrettyPrint", txt, enc)
-}
+  txt <- paste(as.character(txt), collapse = "\n")
+  enc <- mapEncoding(Encoding(txt))
+  .Call("R_jsonPrettyPrint", txt, enc)
+} 
